searchData={"content_type":"text/markdown","items":[{"doc":"Supabase.Storage Elixir Package\n\nThis module provides integration with the Supabase Storage API, enabling developers\nto perform a multitude of operations related to buckets and objects with ease.","ref":"Supabase.Storage.html","title":"Supabase.Storage","type":"module"},{"doc":"1. **Bucket Operations**: Methods that allow the creation, listing, and removal of buckets.\n2. **Object Operations**: Functions designed to upload, download, retrieve object information,\n   and perform move, copy, and remove actions on objects.","ref":"Supabase.Storage.html#module-features","title":"Features - Supabase.Storage","type":"module"},{"doc":"You can start by creating or managing buckets:\n\n    Supabase.Storage.create_bucket(client, \"my_new_bucket\")\n\nOnce a bucket is set up, objects within the bucket can be managed:\n\n    Supabase.Storage.upload_object(client, \"my_bucket\", \"path/on/server.png\", \"path/on/local.png\")","ref":"Supabase.Storage.html#module-usage","title":"Usage - Supabase.Storage","type":"module"},{"doc":"Here are some basic examples:\n\n    # Removing an object\n    Supabase.Storage.remove_object(client, \"my_bucket\", \"path/on/server.png\")\n\n    # Moving an object\n    Supabase.Storage.move_object(client, \"my_bucket\", \"path/on/server1.png\", \"path/on/server2.png\")\n\nEnsure to refer to method-specific documentation for detailed examples and explanations.","ref":"Supabase.Storage.html#module-examples","title":"Examples - Supabase.Storage","type":"module"},{"doc":"Do remember to check and set the appropriate permissions in Supabase to make sure that the\noperations can be performed without any hitches.","ref":"Supabase.Storage.html#module-permissions","title":"Permissions - Supabase.Storage","type":"module"},{"doc":"Copies a object from a bucket and send it to another bucket, in the current project.\nNotice that isn't necessary to pass the current bucket, because the object already\ncontains this information.","ref":"Supabase.Storage.html#copy_object/4","title":"Supabase.Storage.copy_object/4","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `create`","ref":"Supabase.Storage.html#copy_object/4-notes","title":"Notes - Supabase.Storage.copy_object/4","type":"function"},{"doc":"iex> Supabase.Storage.copy_object(client, bucket, object)\n    {:ok, :copied}\n\n    iex> Supabase.Storage.copy_object(invalid_conn, bucket, object)\n    {:error, reason}","ref":"Supabase.Storage.html#copy_object/4-examples","title":"Examples - Supabase.Storage.copy_object/4","type":"function"},{"doc":"Creates a new bucket in the current project given a map of attributes.","ref":"Supabase.Storage.html#create_bucket/2","title":"Supabase.Storage.create_bucket/2","type":"function"},{"doc":"* `id`: the id of the bucket to be created, required\n* `name`: the name of the bucket to be created, defaults to the `id` provided\n* `file_size_limit`: the maximum size of a file in bytes\n* `allowed_mime_types`: a list of allowed mime types, defaults to allow all MIME types\n* `public`: whether the bucket is public or not, defaults to `false`","ref":"Supabase.Storage.html#create_bucket/2-attributes","title":"Attributes - Supabase.Storage.create_bucket/2","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: `insert`\n  * `objects` permissions: none","ref":"Supabase.Storage.html#create_bucket/2-notes","title":"Notes - Supabase.Storage.create_bucket/2","type":"function"},{"doc":"iex> Supabase.Storage.create_bucket(client, %{id: \"avatars\"})\n    {:ok, %Supabase.Storage.Bucket{...}}\n\n    iex> Supabase.Storage.create_bucket(invalid_conn, %{id: \"avatars\"})\n    {:error, reason}","ref":"Supabase.Storage.html#create_bucket/2-examples","title":"Examples - Supabase.Storage.create_bucket/2","type":"function"},{"doc":"Creates a signed URL for an object in a bucket in the current project. This URL can\nbe used to perform an HTTP request to the object, without the need of authentication.\nUsually this is used to allow users to download objects from a bucket.","ref":"Supabase.Storage.html#create_signed_url/4","title":"Supabase.Storage.create_signed_url/4","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `select`","ref":"Supabase.Storage.html#create_signed_url/4-notes","title":"Notes - Supabase.Storage.create_signed_url/4","type":"function"},{"doc":"iex> Supabase.Storage.create_signed_url(client, bucket, \"avatars/some.png\", 3600)\n     {:ok, \"https:// .supabase.co\"/object/sign/ / ?token= }\n\n     iex> Supabase.Storage.create_signed_url(invalid_client, bucket, \"avatars/some.png\", 3600)\n     {:error, :invalid_client}","ref":"Supabase.Storage.html#create_signed_url/4-examples","title":"Examples - Supabase.Storage.create_signed_url/4","type":"function"},{"doc":"Deletes a bucket in the current project. Notice that this also deletes all objects in the bucket.","ref":"Supabase.Storage.html#delete_bucket/2","title":"Supabase.Storage.delete_bucket/2","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: `delete`\n  * `objects` permissions: `delete`","ref":"Supabase.Storage.html#delete_bucket/2-notes","title":"Notes - Supabase.Storage.delete_bucket/2","type":"function"},{"doc":"iex> Supabase.Storage.delete_bucket(client, bucket)\n    {:ok, :deleted}\n\n    iex> Supabase.Storage.delete_bucket(invalid_conn, bucket)\n    {:error, reason}","ref":"Supabase.Storage.html#delete_bucket/2-examples","title":"Examples - Supabase.Storage.delete_bucket/2","type":"function"},{"doc":"Downloads an object from a bucket in the current project. That return a binary that\nrepresents the object content.","ref":"Supabase.Storage.html#download_object/3","title":"Supabase.Storage.download_object/3","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `select`","ref":"Supabase.Storage.html#download_object/3-notes","title":"Notes - Supabase.Storage.download_object/3","type":"function"},{"doc":"iex> Supabase.Storage.download_object(client, %Bucket{}, \"avatars/some.png\")\n     {:ok, <<>>}\n\n     iex> Supabase.Storage.download_object(invalid_conn, %Bucket{}, \"avatars/some.png\")\n     {:error, reason}","ref":"Supabase.Storage.html#download_object/3-examples","title":"Examples - Supabase.Storage.download_object/3","type":"function"},{"doc":"Downloads an object from a bucket in the current project. That return a stream that\nrepresents the object content. Notice that the request to the server is only made\nwhen you start to consume the stream.","ref":"Supabase.Storage.html#download_object_lazy/3","title":"Supabase.Storage.download_object_lazy/3","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `select`","ref":"Supabase.Storage.html#download_object_lazy/3-notes","title":"Notes - Supabase.Storage.download_object_lazy/3","type":"function"},{"doc":"iex> Supabase.Storage.download_object_lazy(client, %Bucket{}, \"avatars/some.png\")\n     {:ok, #Function<59.128620087/2 in Stream.resource/3>}\n\n     iex> Supabase.Storage.download_object_lazy(invalid_conn, %Bucket{}, \"avatars/some.png\")\n     {:error, reason}","ref":"Supabase.Storage.html#download_object_lazy/3-examples","title":"Examples - Supabase.Storage.download_object_lazy/3","type":"function"},{"doc":"Empties a bucket in the current project. This action deletes all objects in the bucket.","ref":"Supabase.Storage.html#empty_bucket/2","title":"Supabase.Storage.empty_bucket/2","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: `update`\n  * `objects` permissions: `delete`","ref":"Supabase.Storage.html#empty_bucket/2-notes","title":"Notes - Supabase.Storage.empty_bucket/2","type":"function"},{"doc":"iex> Supabase.Storage.empty_bucket(client, bucket)\n    {:ok, :emptied}\n\n    iex> Supabase.Storage.empty_bucket(invalid_conn, bucket)\n    {:error, reason}","ref":"Supabase.Storage.html#empty_bucket/2-examples","title":"Examples - Supabase.Storage.empty_bucket/2","type":"function"},{"doc":"Retrieves information about all buckets in the current project.","ref":"Supabase.Storage.html#list_buckets/1","title":"Supabase.Storage.list_buckets/1","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: `select`\n  * `objects` permissions: none","ref":"Supabase.Storage.html#list_buckets/1-notes","title":"Notes - Supabase.Storage.list_buckets/1","type":"function"},{"doc":"iex> Supabase.Storage.list_buckets(client)\n    {:ok, [%Supabase.Storage.Bucket{...}, ...]}\n\n    iex> Supabase.Storage.list_buckets(invalid_conn)\n    {:error, reason}","ref":"Supabase.Storage.html#list_buckets/1-examples","title":"Examples - Supabase.Storage.list_buckets/1","type":"function"},{"doc":"Lists a set of objects in a bucket in the current project.","ref":"Supabase.Storage.html#list_objects/4","title":"Supabase.Storage.list_objects/4","type":"function"},{"doc":"You can pass a prefix to filter the objects returned. For example, if you have the following\nobjects in your bucket:\n\n    .\n    └── bucket/\n        ├── avatars/\n        │   └── some.png\n        ├── other.png\n        └── some.pdf\n\nAnd you want to list only the objects inside the `avatars` folder, you can do:\n\n    iex> Supabase.Storage.list_objects(client, bucket, \"avatars/\")\n    {:ok, [%Supabase.Storage.Object{...}]}\n\nAlso you can pass some search options as a `Supabase.Storage.SearchOptions` struct. Available\noptions are:\n\n* `limit`: the maximum number of objects to return\n* `offset`: the number of objects to skip\n* `sort_by`:\n  * `column`: the column to sort by, defaults to `created_at`\n  * `order`: the order to sort by, defaults to `desc`","ref":"Supabase.Storage.html#list_objects/4-searching","title":"Searching - Supabase.Storage.list_objects/4","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `select`","ref":"Supabase.Storage.html#list_objects/4-notes","title":"Notes - Supabase.Storage.list_objects/4","type":"function"},{"doc":"iex> Supabase.Storage.list_objects(client, bucket)\n    {:ok, [%Supabase.Storage.Object{...}, ...]}\n\n    iex> Supabase.Storage.list_objects(invalid_conn, bucket)\n    {:error, reason}","ref":"Supabase.Storage.html#list_objects/4-examples","title":"Examples - Supabase.Storage.list_objects/4","type":"function"},{"doc":"Moves a object from a bucket and send it to another bucket, in the current project.\nNotice that isn't necessary to pass the current bucket, because the object already\ncontains this information.","ref":"Supabase.Storage.html#move_object/4","title":"Supabase.Storage.move_object/4","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `delete` and `create`","ref":"Supabase.Storage.html#move_object/4-notes","title":"Notes - Supabase.Storage.move_object/4","type":"function"},{"doc":"iex> Supabase.Storage.move_object(client, bucket, object)\n    {:ok, :moved}\n\n    iex> Supabase.Storage.move_object(invalid_conn, bucket, object)\n    {:error, reason}","ref":"Supabase.Storage.html#move_object/4-examples","title":"Examples - Supabase.Storage.move_object/4","type":"function"},{"doc":"Removes an object from a bucket in the current project.","ref":"Supabase.Storage.html#remove_object/3","title":"Supabase.Storage.remove_object/3","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `delete`","ref":"Supabase.Storage.html#remove_object/3-notes","title":"Notes - Supabase.Storage.remove_object/3","type":"function"},{"doc":"iex> Supabase.Storage.remove_object(client, bucket, object)\n    {:ok, :deleted}\n\n    iex> Supabase.Storage.remove_object(invalid_conn, bucket, object)\n    {:error, reason}","ref":"Supabase.Storage.html#remove_object/3-examples","title":"Examples - Supabase.Storage.remove_object/3","type":"function"},{"doc":"Retrieves information about a bucket in the current project.","ref":"Supabase.Storage.html#retrieve_bucket_info/2","title":"Supabase.Storage.retrieve_bucket_info/2","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: `select`\n  * `objects` permissions: none","ref":"Supabase.Storage.html#retrieve_bucket_info/2-notes","title":"Notes - Supabase.Storage.retrieve_bucket_info/2","type":"function"},{"doc":"iex> Supabase.Storage.retrieve_bucket_info(client, \"avatars\")\n    {:ok, %Supabase.Storage.Bucket{...}}\n\n    iex> Supabase.Storage.retrieve_bucket_info(invalid_conn, \"avatars\")\n    {:error, reason}","ref":"Supabase.Storage.html#retrieve_bucket_info/2-examples","title":"Examples - Supabase.Storage.retrieve_bucket_info/2","type":"function"},{"doc":"Retrieves information about an object in a bucket in the current project.","ref":"Supabase.Storage.html#retrieve_object_info/3","title":"Supabase.Storage.retrieve_object_info/3","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `select`","ref":"Supabase.Storage.html#retrieve_object_info/3-notes","title":"Notes - Supabase.Storage.retrieve_object_info/3","type":"function"},{"doc":"iex> Supabase.Storage.retrieve_object_info(client, bucket, \"some.png\")\n    {:ok, %Supabase.Storage.Object{...}}\n\n    iex> Supabase.Storage.retrieve_object_info(invalid_conn, bucket, \"some.png\")\n    {:error, reason}","ref":"Supabase.Storage.html#retrieve_object_info/3-examples","title":"Examples - Supabase.Storage.retrieve_object_info/3","type":"function"},{"doc":"Saves an object from a bucket in the current project to a file in the local filesystem.","ref":"Supabase.Storage.html#save_object/4","title":"Supabase.Storage.save_object/4","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `select`","ref":"Supabase.Storage.html#save_object/4-notes","title":"Notes - Supabase.Storage.save_object/4","type":"function"},{"doc":"iex> Supabase.Storage.save_object(client, \"./some.png\", %Bucket{}, \"avatars/some.png\")\n     :ok\n\n     iex> Supabase.Storage.save_object(client, \"./some.png\", %Bucket{}, \"do_not_exist.png\")\n     {:error, reason}","ref":"Supabase.Storage.html#save_object/4-examples","title":"Examples - Supabase.Storage.save_object/4","type":"function"},{"doc":"Saves an object from a bucket in the current project to a file in the local filesystem.\nNotice that the request to the server is only made when you start to consume the stream.","ref":"Supabase.Storage.html#save_object_stream/4","title":"Supabase.Storage.save_object_stream/4","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `select`","ref":"Supabase.Storage.html#save_object_stream/4-notes","title":"Notes - Supabase.Storage.save_object_stream/4","type":"function"},{"doc":"iex> Supabase.Storage.save_object_stream(client, \"./some.png\", %Bucket{}, \"avatars/some.png\")\n     :ok\n\n     iex> Supabase.Storage.save_object_stream(client, \"./some.png\", %Bucket{}, \"do_not_exist.png\")\n     {:error, reason}","ref":"Supabase.Storage.html#save_object_stream/4-examples","title":"Examples - Supabase.Storage.save_object_stream/4","type":"function"},{"doc":"Updates a bucket in the current project given a map of attributes.","ref":"Supabase.Storage.html#update_bucket/3","title":"Supabase.Storage.update_bucket/3","type":"function"},{"doc":"* `file_size_limit`: the maximum size of a file in bytes\n* `allowed_mime_types`: a list of allowed mime types, defaults to allow all MIME types\n* `public`: whether the bucket is public or not, defaults to `false`\n\nIsn't possible to update a bucket's `id` or `name`. If you want or need this, you should\nfirstly delete the bucket and then create a new one.","ref":"Supabase.Storage.html#update_bucket/3-attributes","title":"Attributes - Supabase.Storage.update_bucket/3","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: `update`\n  * `objects` permissions: none","ref":"Supabase.Storage.html#update_bucket/3-notes","title":"Notes - Supabase.Storage.update_bucket/3","type":"function"},{"doc":"iex> Supabase.Storage.update_bucket(client, bucket, %{public: true})\n    {:ok, %Supabase.Storage.Bucket{...}}\n\n    iex> Supabase.Storage.update_bucket(invalid_conn, bucket, %{public: true})\n    {:error, reason}","ref":"Supabase.Storage.html#update_bucket/3-examples","title":"Examples - Supabase.Storage.update_bucket/3","type":"function"},{"doc":"Uploads a file to a bucket in the current project. Notice that you only need to\npass the path to the file you want to upload, as the file will be read in a stream way\nto be sent to the server.","ref":"Supabase.Storage.html#upload_object/5","title":"Supabase.Storage.upload_object/5","type":"function"},{"doc":"You can pass some options as a `Supabase.Storage.ObjectOptions` struct. Available\noptions are:\n\n* `cache_control`: the cache control header value, defaults to `3600`\n* `content_type`: the content type header value, defaults to `text/plain;charset=UTF-8`\n* `upsert`: whether to overwrite the object if it already exists, defaults to `false`","ref":"Supabase.Storage.html#upload_object/5-options","title":"Options - Supabase.Storage.upload_object/5","type":"function"},{"doc":"* Policy permissions required\n  * `buckets` permissions: none\n  * `objects` permissions: `insert`","ref":"Supabase.Storage.html#upload_object/5-notes","title":"Notes - Supabase.Storage.upload_object/5","type":"function"},{"doc":"iex> Supabase.Storage.upload_object(client, bucket, \"avatars/some.png\", \"path/to/file.png\")\n    {:ok, %Supabase.Storage.Object{...}}\n\n    iex> Supabase.Storage.upload_object(invalid_conn, bucket, \"avatars/some.png\", \"path/to/file.png\")\n    {:error, reason}","ref":"Supabase.Storage.html#upload_object/5-examples","title":"Examples - Supabase.Storage.upload_object/5","type":"function"},{"doc":"Represents a Bucket on Supabase Storage.\n\nThis module defines the structure and operations related to a storage bucket on Supabase.","ref":"Supabase.Storage.Bucket.html","title":"Supabase.Storage.Bucket","type":"module"},{"doc":"A `Bucket` consists of:\n\n- `id`: The unique identifier for the bucket.\n- `name`: The display name of the bucket.\n- `owner`: The owner of the bucket.\n- `file_size_limit`: The maximum file size allowed in the bucket (in bytes). Can be `nil` for no limit.\n- `allowed_mime_types`: List of MIME types permitted in this bucket. Can be `nil` for no restrictions.\n- `created_at`: Timestamp indicating when the bucket was created.\n- `updated_at`: Timestamp indicating the last update to the bucket.\n- `public`: Boolean flag determining if the bucket is publicly accessible or not.","ref":"Supabase.Storage.Bucket.html#module-structure","title":"Structure - Supabase.Storage.Bucket","type":"module"},{"doc":"- `parse!/1`: Parses and returns a bucket structure.\n- `create_changeset/1`: Generates a changeset for creating a bucket.\n- `update_changeset/2`: Generates a changeset for updating an existing bucket.","ref":"Supabase.Storage.Bucket.html#module-functions","title":"Functions - Supabase.Storage.Bucket","type":"module"},{"doc":"","ref":"Supabase.Storage.Bucket.html#module-examples","title":"Examples - Supabase.Storage.Bucket","type":"module"},{"doc":"bucket_attrs = %{\n      id: \"bucket_id\",\n      name: \"My Bucket\",\n      ...\n    }\n    Supabase.Storage.Bucket.parse!(bucket_attrs)","ref":"Supabase.Storage.Bucket.html#module-parsing-a-bucket","title":"Parsing a bucket - Supabase.Storage.Bucket","type":"module"},{"doc":"new_bucket_attrs = %{\n      id: \"new_bucket_id\",\n      ...\n    }\n    Supabase.Storage.Bucket.create_changeset(new_bucket_attrs)","ref":"Supabase.Storage.Bucket.html#module-creating-a-bucket-changeset","title":"Creating a bucket changeset - Supabase.Storage.Bucket","type":"module"},{"doc":"existing_bucket = %Supabase.Storage.Bucket{\n      id: \"existing_bucket_id\",\n      ...\n    }\n    updated_attrs = %{\n      public: true\n    }\n    Supabase.Storage.Bucket.update_changeset(existing_bucket, updated_attrs)","ref":"Supabase.Storage.Bucket.html#module-updating-a-bucket","title":"Updating a bucket - Supabase.Storage.Bucket","type":"module"},{"doc":"","ref":"Supabase.Storage.Bucket.html#create_changeset/1","title":"Supabase.Storage.Bucket.create_changeset/1","type":"function"},{"doc":"","ref":"Supabase.Storage.Bucket.html#parse!/1","title":"Supabase.Storage.Bucket.parse!/1","type":"function"},{"doc":"","ref":"Supabase.Storage.Bucket.html#update_changeset/2","title":"Supabase.Storage.Bucket.update_changeset/2","type":"function"},{"doc":"","ref":"Supabase.Storage.Bucket.html#t:t/0","title":"Supabase.Storage.Bucket.t/0","type":"type"},{"doc":"Provides low-level API functions for managing Supabase Storage buckets.\n\nThe `BucketHandler` module offers a collection of functions that directly interact with the Supabase Storage API for managing buckets. This module works closely with the `Supabase.Fetcher` for sending HTTP requests.","ref":"Supabase.Storage.BucketHandler.html","title":"Supabase.Storage.BucketHandler","type":"module"},{"doc":"- **Bucket Listing**: Fetch a list of all the buckets available in the storage.\n- **Bucket Retrieval**: Retrieve detailed information about a specific bucket.\n- **Bucket Creation**: Create a new bucket with specified attributes.\n- **Bucket Update**: Modify the attributes of an existing bucket.\n- **Bucket Emptying**: Empty the contents of a bucket without deleting the bucket itself.\n- **Bucket Deletion**: Permanently remove a bucket and its contents.","ref":"Supabase.Storage.BucketHandler.html#module-features","title":"Features - Supabase.Storage.BucketHandler","type":"module"},{"doc":"This module provides a low-level interface to Supabase Storage buckets and is designed for internal use by the `Supabase.Storage` module. Direct use is discouraged unless you need to perform custom or unsupported actions that are not available through the higher-level API. Incorrect use can lead to unexpected results or data loss.","ref":"Supabase.Storage.BucketHandler.html#module-caution","title":"Caution - Supabase.Storage.BucketHandler","type":"module"},{"doc":"All functions within the module expect a base URL, API key, and access token as their initial arguments, followed by any additional arguments required for the specific operation. Responses are usually in the form of `{:ok, result}` or `{:error, message}` tuples.","ref":"Supabase.Storage.BucketHandler.html#module-implementation-details","title":"Implementation Details - Supabase.Storage.BucketHandler","type":"module"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#create/2","title":"Supabase.Storage.BucketHandler.create/2","type":"function"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#delete/2","title":"Supabase.Storage.BucketHandler.delete/2","type":"function"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#empty/2","title":"Supabase.Storage.BucketHandler.empty/2","type":"function"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#list/1","title":"Supabase.Storage.BucketHandler.list/1","type":"function"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#retrieve_info/2","title":"Supabase.Storage.BucketHandler.retrieve_info/2","type":"function"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#update/3","title":"Supabase.Storage.BucketHandler.update/3","type":"function"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#t:bucket_id/0","title":"Supabase.Storage.BucketHandler.bucket_id/0","type":"type"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#t:bucket_name/0","title":"Supabase.Storage.BucketHandler.bucket_name/0","type":"type"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#t:create_attrs/0","title":"Supabase.Storage.BucketHandler.create_attrs/0","type":"type"},{"doc":"","ref":"Supabase.Storage.BucketHandler.html#t:update_attrs/0","title":"Supabase.Storage.BucketHandler.update_attrs/0","type":"type"},{"doc":"Defines the Endpoints for the Supabase Storage API","ref":"Supabase.Storage.Endpoints.html","title":"Supabase.Storage.Endpoints","type":"module"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#bucket_path/0","title":"Supabase.Storage.Endpoints.bucket_path/0","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#bucket_path_to_empty/1","title":"Supabase.Storage.Endpoints.bucket_path_to_empty/1","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#bucket_path_with_id/1","title":"Supabase.Storage.Endpoints.bucket_path_with_id/1","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_copy/0","title":"Supabase.Storage.Endpoints.file_copy/0","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_download/2","title":"Supabase.Storage.Endpoints.file_download/2","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_info/2","title":"Supabase.Storage.Endpoints.file_info/2","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_list/1","title":"Supabase.Storage.Endpoints.file_list/1","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_move/0","title":"Supabase.Storage.Endpoints.file_move/0","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_remove/1","title":"Supabase.Storage.Endpoints.file_remove/1","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_signed_url/2","title":"Supabase.Storage.Endpoints.file_signed_url/2","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_upload/2","title":"Supabase.Storage.Endpoints.file_upload/2","type":"function"},{"doc":"","ref":"Supabase.Storage.Endpoints.html#file_upload_url/1","title":"Supabase.Storage.Endpoints.file_upload_url/1","type":"function"},{"doc":"Represents an Object within a Supabase Storage Bucket.\n\nThis module encapsulates the structure and operations related to an object or file stored within a Supabase Storage bucket.","ref":"Supabase.Storage.Object.html","title":"Supabase.Storage.Object","type":"module"},{"doc":"An `Object` has the following attributes:\n\n- `id`: The unique identifier for the object.\n- `path`: The path to the object within its storage bucket.\n- `bucket_id`: The ID of the bucket that houses this object.\n- `name`: The name or title of the object.\n- `owner`: The owner or uploader of the object.\n- `metadata`: A map containing meta-information about the object (e.g., file type, size).\n- `created_at`: Timestamp indicating when the object was first uploaded or created.\n- `updated_at`: Timestamp indicating the last time the object was updated.\n- `last_accessed_at`: Timestamp of when the object was last accessed or retrieved.","ref":"Supabase.Storage.Object.html#module-structure","title":"Structure - Supabase.Storage.Object","type":"module"},{"doc":"- `parse!/1`: Accepts a map of attributes and constructs a structured `Object`.","ref":"Supabase.Storage.Object.html#module-functions","title":"Functions - Supabase.Storage.Object","type":"module"},{"doc":"","ref":"Supabase.Storage.Object.html#module-examples","title":"Examples - Supabase.Storage.Object","type":"module"},{"doc":"object_attrs = %{\n      id: \"obj_id\",\n      path: \"/folder/my_file.txt\",\n      bucket_id: \"bucket_123\",\n      ...\n    }\n    Supabase.Storage.Object.parse!(object_attrs)","ref":"Supabase.Storage.Object.html#module-parsing-an-object","title":"Parsing an object - Supabase.Storage.Object","type":"module"},{"doc":"","ref":"Supabase.Storage.Object.html#parse!/1","title":"Supabase.Storage.Object.parse!/1","type":"function"},{"doc":"","ref":"Supabase.Storage.Object.html#t:t/0","title":"Supabase.Storage.Object.t/0","type":"type"},{"doc":"A low-level API interface for managing objects within a Supabase bucket.","ref":"Supabase.Storage.ObjectHandler.html","title":"Supabase.Storage.ObjectHandler","type":"module"},{"doc":"- **File Management**: Create, move, copy, and get information about files in a bucket.\n- **Object Listing**: List objects based on certain criteria, like a prefix.\n- **Object Removal**: Delete specific objects or a list of objects.\n- **URL Management**: Generate signed URLs for granting temporary access to objects.\n- **Content Access**: Retrieve the content of an object or stream it.","ref":"Supabase.Storage.ObjectHandler.html#module-responsibilities","title":"Responsibilities - Supabase.Storage.ObjectHandler","type":"module"},{"doc":"This module is meant for internal use or for developers requiring more control over object management in Supabase. In general, users should work with the higher-level Supabase.Storage API when possible, as it may offer better abstractions and safety mechanisms.\n\nDirectly interfacing with this module bypasses any additional logic the main API might provide. Use it with caution and ensure you understand its operations.","ref":"Supabase.Storage.ObjectHandler.html#module-usage-warning","title":"Usage Warning - Supabase.Storage.ObjectHandler","type":"module"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#copy/4","title":"Supabase.Storage.ObjectHandler.copy/4","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#create_file/5","title":"Supabase.Storage.ObjectHandler.create_file/5","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#create_signed_url/4","title":"Supabase.Storage.ObjectHandler.create_signed_url/4","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#get/3","title":"Supabase.Storage.ObjectHandler.get/3","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#get_info/3","title":"Supabase.Storage.ObjectHandler.get_info/3","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#get_lazy/3","title":"Supabase.Storage.ObjectHandler.get_lazy/3","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#list/4","title":"Supabase.Storage.ObjectHandler.list/4","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#move/4","title":"Supabase.Storage.ObjectHandler.move/4","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#remove/3","title":"Supabase.Storage.ObjectHandler.remove/3","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#remove_list/3","title":"Supabase.Storage.ObjectHandler.remove_list/3","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#t:bucket_name/0","title":"Supabase.Storage.ObjectHandler.bucket_name/0","type":"type"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#t:file_path/0","title":"Supabase.Storage.ObjectHandler.file_path/0","type":"type"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#t:object_path/0","title":"Supabase.Storage.ObjectHandler.object_path/0","type":"type"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#t:opts/0","title":"Supabase.Storage.ObjectHandler.opts/0","type":"type"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#t:prefix/0","title":"Supabase.Storage.ObjectHandler.prefix/0","type":"type"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#t:search_opts/0","title":"Supabase.Storage.ObjectHandler.search_opts/0","type":"type"},{"doc":"","ref":"Supabase.Storage.ObjectHandler.html#t:wildcard/0","title":"Supabase.Storage.ObjectHandler.wildcard/0","type":"type"},{"doc":"Represents the configurable options for an Object within Supabase Storage.\n\nThis module encapsulates options that can be set or modified for a storage object. These options help in controlling behavior such as caching, content type, and whether to upsert an object.","ref":"Supabase.Storage.ObjectOptions.html","title":"Supabase.Storage.ObjectOptions","type":"module"},{"doc":"An `ObjectOptions` consists of the following attributes:\n\n- `cache_control`: Specifies directives for caching mechanisms in both requests and responses. Default is `\"3600\"`.\n- `content_type`: Specifies the media type of the resource or data. Default is `\"text/plain;charset=UTF-8\"`.\n- `upsert`: A boolean that, when set to `true`, will insert the object if it does not exist, or update it if it does. Default is `true`.","ref":"Supabase.Storage.ObjectOptions.html#module-structure","title":"Structure - Supabase.Storage.ObjectOptions","type":"module"},{"doc":"- `parse!/1`: Accepts a map of attributes and constructs a structured `ObjectOptions`.","ref":"Supabase.Storage.ObjectOptions.html#module-functions","title":"Functions - Supabase.Storage.ObjectOptions","type":"module"},{"doc":"","ref":"Supabase.Storage.ObjectOptions.html#module-examples","title":"Examples - Supabase.Storage.ObjectOptions","type":"module"},{"doc":"options_attrs = %{\n      cache_control: \"no-cache\",\n      content_type: \"application/json\",\n      upsert: false\n    }\n    Supabase.Storage.ObjectOptions.parse!(options_attrs)","ref":"Supabase.Storage.ObjectOptions.html#module-parsing-object-options","title":"Parsing object options - Supabase.Storage.ObjectOptions","type":"module"},{"doc":"","ref":"Supabase.Storage.ObjectOptions.html#parse!/1","title":"Supabase.Storage.ObjectOptions.parse!/1","type":"function"},{"doc":"","ref":"Supabase.Storage.ObjectOptions.html#t:t/0","title":"Supabase.Storage.ObjectOptions.t/0","type":"type"},{"doc":"Represents the search options for querying objects within Supabase Storage.\n\nThis module encapsulates various options that aid in fetching and sorting storage objects. These options include specifying the limit on the number of results, an offset for pagination, and a sorting directive.","ref":"Supabase.Storage.SearchOptions.html","title":"Supabase.Storage.SearchOptions","type":"module"},{"doc":"A `SearchOptions` consists of the following attributes:\n\n- `limit`: Specifies the maximum number of results to return. Default is `100`.\n- `offset`: Specifies the number of results to skip before starting to fetch the result set. Useful for implementing pagination. Default is `0`.\n- `sort_by`: A map that provides a sorting directive. It defines which column should be used for sorting and the order (ascending or descending). Default is `%{column: \"name\", order: \"asc\"}`.","ref":"Supabase.Storage.SearchOptions.html#module-structure","title":"Structure - Supabase.Storage.SearchOptions","type":"module"},{"doc":"- `parse!/1`: Accepts a map of attributes and constructs a structured `SearchOptions`.","ref":"Supabase.Storage.SearchOptions.html#module-functions","title":"Functions - Supabase.Storage.SearchOptions","type":"module"},{"doc":"","ref":"Supabase.Storage.SearchOptions.html#module-examples","title":"Examples - Supabase.Storage.SearchOptions","type":"module"},{"doc":"search_attrs = %{\n      limit: 50,\n      offset: 10,\n      sort_by: %{column: \"created_at\", order: \"desc\"}\n    }\n    Supabase.Storage.SearchOptions.parse!(search_attrs)","ref":"Supabase.Storage.SearchOptions.html#module-parsing-search-options","title":"Parsing search options - Supabase.Storage.SearchOptions","type":"module"},{"doc":"","ref":"Supabase.Storage.SearchOptions.html#parse!/1","title":"Supabase.Storage.SearchOptions.parse!/1","type":"function"},{"doc":"","ref":"Supabase.Storage.SearchOptions.html#t:t/0","title":"Supabase.Storage.SearchOptions.t/0","type":"type"},{"doc":"Defines Supabase Storage Client callbacks","ref":"Supabase.StorageBehaviour.html","title":"Supabase.StorageBehaviour","type":"behaviour"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:copy_object/4","title":"Supabase.StorageBehaviour.copy_object/4","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:create_bucket/2","title":"Supabase.StorageBehaviour.create_bucket/2","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:create_signed_url/4","title":"Supabase.StorageBehaviour.create_signed_url/4","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:delete_bucket/2","title":"Supabase.StorageBehaviour.delete_bucket/2","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:download_object/3","title":"Supabase.StorageBehaviour.download_object/3","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:download_object_lazy/3","title":"Supabase.StorageBehaviour.download_object_lazy/3","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:empty_bucket/2","title":"Supabase.StorageBehaviour.empty_bucket/2","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:list_buckets/1","title":"Supabase.StorageBehaviour.list_buckets/1","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:list_objects/4","title":"Supabase.StorageBehaviour.list_objects/4","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:move_object/4","title":"Supabase.StorageBehaviour.move_object/4","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:remove_object/3","title":"Supabase.StorageBehaviour.remove_object/3","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:retrieve_bucket_info/2","title":"Supabase.StorageBehaviour.retrieve_bucket_info/2","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:retrieve_object_info/3","title":"Supabase.StorageBehaviour.retrieve_object_info/3","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:save_object/4","title":"Supabase.StorageBehaviour.save_object/4","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:save_object_stream/4","title":"Supabase.StorageBehaviour.save_object_stream/4","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:update_bucket/3","title":"Supabase.StorageBehaviour.update_bucket/3","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#c:upload_object/5","title":"Supabase.StorageBehaviour.upload_object/5","type":"callback"},{"doc":"","ref":"Supabase.StorageBehaviour.html#t:conn/0","title":"Supabase.StorageBehaviour.conn/0","type":"type"},{"doc":"","ref":"Supabase.StorageBehaviour.html#t:reason/0","title":"Supabase.StorageBehaviour.reason/0","type":"type"},{"doc":"","ref":"Supabase.StorageBehaviour.html#t:result/1","title":"Supabase.StorageBehaviour.result/1","type":"type"},{"doc":"Represents an Error on a Supabase Storage Action","ref":"Supabase.Storage.ActionError.html","title":"Supabase.Storage.ActionError","type":"exception"},{"doc":"# Supabase Storage\n\n[Storage]() implementation for the `supabase_potion` SDK in Elixir.","ref":"readme.html","title":"Supabase Storage","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.3\"},\n    {:supabase_storage, \"~> 0.2\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Supabase Storage","type":"extras"},{"doc":"Firstly you need to initialize your Supabase client(s) as can be found on the [supabase_potion documentation]():\n\n```elixir\niex> Supabase.init_client(%{name: Conn, conn: %{base_url: \" \", api_key: \" \"}})\n{:ok, #PID<>}\n```\n\nNow you can pass the Client to the `Supabase.Storage` functions as a `PID` or the name that was registered on the client initialization:\n\n```elixir\niex> Supabase.Storage.list_buckets(pid | client_name)  \n```","ref":"readme.html#usage","title":"Usage - Supabase Storage","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}